@@ -5,27 +5,18 @@ Created on Apr 30, 2012
 '''
 import numpy as np
 import matplotlib
-
 import matplotlib.pyplot as plt
-
 from argparse import ArgumentParser
-
 from modelr.web.urlargparse import  wavelet_type
-
 from modelr.constants import WAVELETS 
-
 from modelr.web.defaults import default_parsers
-
-
+from agilegeo.util import noise_db, rms
 from modelr.reflectivity import do_convolve
 
 short_description = ("Convolution model with synthetic wavelets")
 
 
 def add_arguments(parser):
-
-    
-    
     
     parser.add_argument('f', type=float, default=12,
                         help="Frequency",
@@ -37,10 +28,10 @@ def add_arguments(parser):
                         interface='slider',
                         range=[-180,180])
 
-    #parser.add_argument('noise', type=float, default=0.0,
-    #                    help="noise",
-    #                    interface='slider',
-    #                    range=[0,100])
+    parser.add_argument('snr', type=float, default=900,
+                        help="Signal:noise (dB)",
+                        interface='slider',
+                        range=[0,1000])
     
     parser.add_argument('wavelet',
                         type=wavelet_type,
@@ -73,7 +64,7 @@ def add_arguments(parser):
     return parser
 
 def run_script(earth_model, seismic_model, theta=None,
-               traces=None):
+               traces=None, snr=50):
 
     if earth_model.reflectivity() is None:
 
@@ -87,14 +78,17 @@ def run_script(earth_model, seismic_model, theta=None,
         earth_model.update_reflectivity(seismic_model.offset_angles(),
                                         seismic_model.n_sensors)
 
-    
+
+    snr_scale = np.linspace(-50,50,1000)
     wavelets = seismic_model.wavelets()
 
     ref = earth_model.reflectivity(theta=theta)
-    #noise = np.random.randn(ref.shape[0], ref.shape[1],
-    #                        ref.shape[2]) * seismic_model.noise
     
-        
+    noise = noise_db(ref, snr_scale[snr])
+
+    
+    ref += noise
+
     seismic = do_convolve(wavelets,
                           ref,
                           traces=traces,
